'''
This script numbers each patch inside of ./cwd/pataches/ starting from 000.
The patches are also numbered in alphabetical order.
Sorted patches are outputted into a new directory: ./cwd/sorted_patches/

Usage:
Make a new directory (cwd)
Place this script in this directory, as well as a folder containing the patches you want to sort (name it "patches")
Open terminal
cd into cwd
run "python sortPatches.py"
The sorted patches will be in ./cwd/sorted_patches/

Have fun!
Author:
    Daniel Gonzalez
    danngonzalez95@gmail.com
'''
import os
import numpy as np
import re
from os import listdir
from os.path import isfile, join

def main():
    # Get files from cwd/patches/*
    old_file_names = [f for f in os.listdir(os.getcwd()+"/patches") if not f.startswith('.')]

    # {patch_name: old_full_name}
    patch_names = {}

    # {old_full_name: new_full_name}
    new_full_names = {}

    # Strip off first 0xx_ and zoia_ string
    for i, old_file_name in enumerate(old_file_names):
        patch_name = re.sub(r'\d+_', '', old_file_name)
        patch_name = re.sub('zoia_', '', patch_name)
        patch_names[patch_name] = old_file_name

    # Alphabetize and create ordered prefixes
    for i, patch_name in enumerate(sorted(patch_names, key=str.lower)):
        old_name = patch_names[patch_name]
        if i < 10:
            new_full_names[old_name] = "00" + str(i) + "_" + patch_name
        else:
            new_full_names[old_name] = "0" + str(i) + "_zoia_" + patch_name

    # Save new patches in a new directory
    os.system('mkdir -p ./sorted_patches')
    os.system('rm -rf ./sorted_patches/*')
    for old_name in new_full_names:
        print(old_name + ": " + new_full_names[old_name])
        os.system('cp ./patches/' + old_name + ' ./sorted_patches/' + new_full_names[old_name])
  
if __name__== "__main__":
  main()